# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _pywsman
else:
    import _pywsman

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)



def fopen(arg1, arg2):
    r"""fopen(char * arg1, char * arg2) -> FILE *"""
    return _pywsman.fopen(arg1, arg2)

def fclose(f):
    r"""fclose(FILE * f)"""
    return _pywsman.fclose(f)
OPENWSMAN_MAJOR = _pywsman.OPENWSMAN_MAJOR

OPENWSMAN_MINOR = _pywsman.OPENWSMAN_MINOR

OPENWSMAN_PATCH = _pywsman.OPENWSMAN_PATCH

OPENWSMAN_VERSION = _pywsman.OPENWSMAN_VERSION

class XmlNs(object):
    r"""Proxy of C __WsXmlNs struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

# Register XmlNs in _pywsman:
_pywsman.XmlNs_swigregister(XmlNs)
class XmlDoc(object):
    r"""Proxy of C _WsXmlDoc struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, name, ns=None):
        r"""__init__(XmlDoc self, char const * name, char const * ns=None) -> XmlDoc"""
        _pywsman.XmlDoc_swiginit(self, _pywsman.new_XmlDoc(name, ns))
    __swig_destroy__ = _pywsman.delete_XmlDoc

    def __str__(self):
        r"""__str__(XmlDoc self) -> char *"""
        return _pywsman.XmlDoc___str__(self)

    def encode(self, *args):
        r"""encode(XmlDoc self, char const * encoding="utf-8") -> char *"""
        return _pywsman.XmlDoc_encode(self, *args)

    def dump_file(self, fp):
        r"""dump_file(XmlDoc self, FILE * fp)"""
        return _pywsman.XmlDoc_dump_file(self, fp)

    def root(self):
        r"""root(XmlDoc self) -> XmlNode"""
        return _pywsman.XmlDoc_root(self)

    def envelope(self):
        r"""envelope(XmlDoc self) -> XmlNode"""
        return _pywsman.XmlDoc_envelope(self)

    def header(self):
        r"""header(XmlDoc self) -> XmlNode"""
        return _pywsman.XmlDoc_header(self)

    def body(self):
        r"""body(XmlDoc self) -> XmlNode"""
        return _pywsman.XmlDoc_body(self)

    def element(self, name):
        r"""element(XmlDoc self, char const * name) -> XmlNode"""
        return _pywsman.XmlDoc_element(self, name)

    def context(self):
        r"""context(XmlDoc self) -> char const *"""
        return _pywsman.XmlDoc_context(self)

    def generate_fault(self, s):
        r"""generate_fault(XmlDoc self, Status s) -> XmlDoc"""
        return _pywsman.XmlDoc_generate_fault(self, s)

    def is_fault(self):
        r"""is_fault(XmlDoc self) -> int"""
        return _pywsman.XmlDoc_is_fault(self)

    def fault(self):
        r"""fault(XmlDoc self) -> Fault"""
        return _pywsman.XmlDoc_fault(self)

    def create_response_envelope(self, action=None):
        r"""create_response_envelope(XmlDoc self, char const * action=None) -> XmlDoc"""
        return _pywsman.XmlDoc_create_response_envelope(self, action)

    def is_end_of_sequence(self):
        r"""is_end_of_sequence(XmlDoc self) -> int"""
        return _pywsman.XmlDoc_is_end_of_sequence(self)

# Register XmlDoc in _pywsman:
_pywsman.XmlDoc_swigregister(XmlDoc)
class XmlNode(object):
    r"""Proxy of C __WsXmlNode struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    __swig_destroy__ = _pywsman.delete_XmlNode

    def string(self):
        r"""string(XmlNode self) -> char *"""
        return _pywsman.XmlNode_string(self)

    def dump_file(self, fp):
        r"""dump_file(XmlNode self, FILE * fp)"""
        return _pywsman.XmlNode_dump_file(self, fp)

    def equal(self, n):
        r"""equal(XmlNode self, XmlNode n) -> int"""
        return _pywsman.XmlNode_equal(self, n)

    def __str__(self):
        r"""__str__(XmlNode self) -> char *"""
        return _pywsman.XmlNode___str__(self)

    def set_text(self, text):
        r"""set_text(XmlNode self, char const * text)"""
        return _pywsman.XmlNode_set_text(self, text)

    def doc(self):
        r"""doc(XmlNode self) -> XmlDoc"""
        return _pywsman.XmlNode_doc(self)

    def parent(self):
        r"""parent(XmlNode self) -> XmlNode"""
        return _pywsman.XmlNode_parent(self)

    def child(self):
        r"""child(XmlNode self) -> XmlNode"""
        return _pywsman.XmlNode_child(self)

    def name(self):
        r"""name(XmlNode self) -> char *"""
        return _pywsman.XmlNode_name(self)

    def set_name(self, name):
        r"""set_name(XmlNode self, char const * name)"""
        return _pywsman.XmlNode_set_name(self, name)

    def ns(self):
        r"""ns(XmlNode self) -> char *"""
        return _pywsman.XmlNode_ns(self)

    def set_ns(self, ns):
        r"""set_ns(XmlNode self, char const * ns)"""
        return _pywsman.XmlNode_set_ns(self, ns)

    def prefix(self):
        r"""prefix(XmlNode self) -> char const *"""
        return _pywsman.XmlNode_prefix(self)

    def set_lang(self, lang):
        r"""set_lang(XmlNode self, char const * lang)"""
        return _pywsman.XmlNode_set_lang(self, lang)

    def find(self, ns, name, recursive=1):
        r"""find(XmlNode self, char const * ns, char const * name, int recursive=1) -> XmlNode"""
        return _pywsman.XmlNode_find(self, ns, name, recursive)

    def next(self, all=0):
        r"""next(XmlNode self, int all=0) -> XmlNode"""
        return _pywsman.XmlNode_next(self, all)

    def size(self, name=None, ns=None):
        r"""size(XmlNode self, char const * name=None, char const * ns=None) -> int"""
        return _pywsman.XmlNode_size(self, name, ns)

    def add_before(self, ns, name, text=None):
        r"""add_before(XmlNode self, char const * ns, char const * name, char const * text=None) -> XmlNode"""
        return _pywsman.XmlNode_add_before(self, ns, name, text)

    def add(self, *args):
        r"""
        add(XmlNode self, char const * ns, char const * name, char const * text=None) -> XmlNode
        add(XmlNode self, XmlNode node) -> XmlNode
        """
        return _pywsman.XmlNode_add(self, *args)

    def __iter__(self):
      r = range(0,self.size())
      while r:
        yield self.get(r.pop(0))


    def get(self, *args):
        r"""
        get(XmlNode self, int i, char const * name=None, char const * ns=None) -> XmlNode
        get(XmlNode self, char const * name, char const * ns=None) -> XmlNode
        """
        return _pywsman.XmlNode_get(self, *args)

    def attr(self, index=0):
        r"""attr(XmlNode self, int index=0) -> XmlAttr"""
        return _pywsman.XmlNode_attr(self, index)

    def attr_count(self):
        r"""attr_count(XmlNode self) -> int"""
        return _pywsman.XmlNode_attr_count(self)

    def attr_find(self, ns, name):
        r"""attr_find(XmlNode self, char const * ns, char const * name) -> XmlAttr"""
        return _pywsman.XmlNode_attr_find(self, ns, name)

    def attr_add(self, ns, name, value):
        r"""attr_add(XmlNode self, char const * ns, char const * name, char const * value) -> XmlAttr"""
        return _pywsman.XmlNode_attr_add(self, ns, name, value)

    def epr(self, ns, epr_node_name, embedded):
        r"""epr(XmlNode self, char const * ns, char const * epr_node_name, int embedded) -> EndPointReference"""
        return _pywsman.XmlNode_epr(self, ns, epr_node_name, embedded)

# Register XmlNode in _pywsman:
_pywsman.XmlNode_swigregister(XmlNode)
class XmlAttr(object):
    r"""Proxy of C __WsXmlAttr struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def name(self):
        r"""name(XmlAttr self) -> char *"""
        return _pywsman.XmlAttr_name(self)

    def ns(self):
        r"""ns(XmlAttr self) -> char *"""
        return _pywsman.XmlAttr_ns(self)

    def value(self):
        r"""value(XmlAttr self) -> char *"""
        return _pywsman.XmlAttr_value(self)

    def remove(self):
        r"""remove(XmlAttr self)"""
        return _pywsman.XmlAttr_remove(self)

# Register XmlAttr in _pywsman:
_pywsman.XmlAttr_swigregister(XmlAttr)
XML_NS_SOAP_1_1 = _pywsman.XML_NS_SOAP_1_1

XML_NS_SOAP_1_2 = _pywsman.XML_NS_SOAP_1_2

XML_NS_XML_NAMESPACES = _pywsman.XML_NS_XML_NAMESPACES

XML_NS_ADDRESSING = _pywsman.XML_NS_ADDRESSING

XML_NS_DISCOVERY = _pywsman.XML_NS_DISCOVERY

XML_NS_EVENTING = _pywsman.XML_NS_EVENTING

XML_NS_ENUMERATION = _pywsman.XML_NS_ENUMERATION

XML_NS_TRANSFER = _pywsman.XML_NS_TRANSFER

XML_NS_XML_SCHEMA = _pywsman.XML_NS_XML_SCHEMA

XML_NS_SCHEMA_INSTANCE = _pywsman.XML_NS_SCHEMA_INSTANCE

XML_NS_POLICY = _pywsman.XML_NS_POLICY

XML_NS_TRUST = _pywsman.XML_NS_TRUST

XML_NS_SE = _pywsman.XML_NS_SE

XML_NS_SCHEMA_INSTANCE_PREFIX = _pywsman.XML_NS_SCHEMA_INSTANCE_PREFIX

XML_NS_SCHEMA_INSTANCE_NIL = _pywsman.XML_NS_SCHEMA_INSTANCE_NIL

XML_NS_OPENWSMAN = _pywsman.XML_NS_OPENWSMAN

XML_NS_CIM_SCHEMA = _pywsman.XML_NS_CIM_SCHEMA

XML_NS_CIM_CLASS = _pywsman.XML_NS_CIM_CLASS

XML_NS_CIM_BINDING = _pywsman.XML_NS_CIM_BINDING

XML_NS_CIM_INTRINSIC = _pywsman.XML_NS_CIM_INTRINSIC

XML_NS_WS_MAN = _pywsman.XML_NS_WS_MAN

XML_NS_WSMAN_FAULT_DETAIL = _pywsman.XML_NS_WSMAN_FAULT_DETAIL

XML_NS_WS_MAN_CAT = _pywsman.XML_NS_WS_MAN_CAT

XML_NS_WSMAN_ID = _pywsman.XML_NS_WSMAN_ID

SOAP1_2_CONTENT_TYPE = _pywsman.SOAP1_2_CONTENT_TYPE

SOAP_CONTENT_TYPE = _pywsman.SOAP_CONTENT_TYPE

CIMXML_CONTENT_TYPE = _pywsman.CIMXML_CONTENT_TYPE

SOAP_SKIP_DEF_FILTERS = _pywsman.SOAP_SKIP_DEF_FILTERS

SOAP_ACTION_PREFIX = _pywsman.SOAP_ACTION_PREFIX

SOAP_ONE_WAY_OP = _pywsman.SOAP_ONE_WAY_OP

SOAP_NO_RESP_OP = _pywsman.SOAP_NO_RESP_OP

SOAP_DONT_KEEP_INDOC = _pywsman.SOAP_DONT_KEEP_INDOC

SOAP_CLIENT_RESPONSE = _pywsman.SOAP_CLIENT_RESPONSE

SOAP_CUSTOM_DISPATCHER = _pywsman.SOAP_CUSTOM_DISPATCHER

SOAP_IDENTIFY_DISPATCH = _pywsman.SOAP_IDENTIFY_DISPATCH

WSMID_IDENTIFY = _pywsman.WSMID_IDENTIFY

WSMID_IDENTIFY_RESPONSE = _pywsman.WSMID_IDENTIFY_RESPONSE

WSMID_PROTOCOL_VERSION = _pywsman.WSMID_PROTOCOL_VERSION

WSMID_PRODUCT_VENDOR = _pywsman.WSMID_PRODUCT_VENDOR

WSMID_PRODUCT_VERSION = _pywsman.WSMID_PRODUCT_VERSION

XML_SCHEMA_NIL = _pywsman.XML_SCHEMA_NIL

WSA_TO_ANONYMOUS = _pywsman.WSA_TO_ANONYMOUS

WSA_MESSAGE_ID = _pywsman.WSA_MESSAGE_ID

WSA_ADDRESS = _pywsman.WSA_ADDRESS

WSA_EPR = _pywsman.WSA_EPR

WSA_ACTION = _pywsman.WSA_ACTION

WSA_RELATES_TO = _pywsman.WSA_RELATES_TO

WSA_TO = _pywsman.WSA_TO

WSA_REPLY_TO = _pywsman.WSA_REPLY_TO

WSA_FROM = _pywsman.WSA_FROM

WSA_FAULT_TO = _pywsman.WSA_FAULT_TO

WSA_REFERENCE_PROPERTIES = _pywsman.WSA_REFERENCE_PROPERTIES

WSA_REFERENCE_PARAMETERS = _pywsman.WSA_REFERENCE_PARAMETERS

WSA_ACTION_FAULT = _pywsman.WSA_ACTION_FAULT

SOAP_ENVELOPE = _pywsman.SOAP_ENVELOPE

SOAP_HEADER = _pywsman.SOAP_HEADER

SOAP_BODY = _pywsman.SOAP_BODY

SOAP_FAULT = _pywsman.SOAP_FAULT

SOAP_CODE = _pywsman.SOAP_CODE

SOAP_VALUE = _pywsman.SOAP_VALUE

SOAP_SUBCODE = _pywsman.SOAP_SUBCODE

SOAP_REASON = _pywsman.SOAP_REASON

SOAP_TEXT = _pywsman.SOAP_TEXT

SOAP_LANG = _pywsman.SOAP_LANG

SOAP_DETAIL = _pywsman.SOAP_DETAIL

SOAP_FAULT_DETAIL = _pywsman.SOAP_FAULT_DETAIL

SOAP_MUST_UNDERSTAND = _pywsman.SOAP_MUST_UNDERSTAND

SOAP_VERSION_MISMATCH = _pywsman.SOAP_VERSION_MISMATCH

SOAP_UPGRADE = _pywsman.SOAP_UPGRADE

SOAP_SUPPORTED_ENVELOPE = _pywsman.SOAP_SUPPORTED_ENVELOPE

TRANSFER_ACTION_GET = _pywsman.TRANSFER_ACTION_GET

TRANSFER_ACTION_GETRESPONSE = _pywsman.TRANSFER_ACTION_GETRESPONSE

TRANSFER_GET = _pywsman.TRANSFER_GET

TRANSFER_GET_RESP = _pywsman.TRANSFER_GET_RESP

TRANSFER_ACTION_PUT = _pywsman.TRANSFER_ACTION_PUT

TRANSFER_ACTION_PUTRESPONSE = _pywsman.TRANSFER_ACTION_PUTRESPONSE

TRANSFER_PUT = _pywsman.TRANSFER_PUT

TRANSFER_PUT_RESP = _pywsman.TRANSFER_PUT_RESP

TRANSFER_ACTION_CREATE = _pywsman.TRANSFER_ACTION_CREATE

TRANSFER_CREATE = _pywsman.TRANSFER_CREATE

TRANSFER_ACTION_DELETE = _pywsman.TRANSFER_ACTION_DELETE

TRANSFER_DELETE = _pywsman.TRANSFER_DELETE

TRANSFER_ACTION_DELETERESPONSE = _pywsman.TRANSFER_ACTION_DELETERESPONSE

TRANSFER_DELETE_RESP = _pywsman.TRANSFER_DELETE_RESP

WSXF_ACTION_FAULT = _pywsman.WSXF_ACTION_FAULT

ENUM_ACTION_ENUMERATE = _pywsman.ENUM_ACTION_ENUMERATE

ENUM_ACTION_ENUMERATERESPONSE = _pywsman.ENUM_ACTION_ENUMERATERESPONSE

WSENUM_ENUMERATE = _pywsman.WSENUM_ENUMERATE

WSENUM_ENUMERATE_RESP = _pywsman.WSENUM_ENUMERATE_RESP

ENUM_ACTION_RELEASE = _pywsman.ENUM_ACTION_RELEASE

WSENUM_RELEASE = _pywsman.WSENUM_RELEASE

WSENUM_RELEASE_RESP = _pywsman.WSENUM_RELEASE_RESP

ENUM_ACTION_PULL = _pywsman.ENUM_ACTION_PULL

WSENUM_PULL = _pywsman.WSENUM_PULL

WSENUM_PULL_RESP = _pywsman.WSENUM_PULL_RESP

ENUM_ACTION_RENEW = _pywsman.ENUM_ACTION_RENEW

ENUM_ACTION_GETSTATUS = _pywsman.ENUM_ACTION_GETSTATUS

ENUM_ACTION_ENUMEND = _pywsman.ENUM_ACTION_ENUMEND

EVT_ACTION_SUBSCRIBE = _pywsman.EVT_ACTION_SUBSCRIBE

WSEVENT_SUBSCRIBE = _pywsman.WSEVENT_SUBSCRIBE

WSEVENT_SUBSCRIBE_RESP = _pywsman.WSEVENT_SUBSCRIBE_RESP

EVT_ACTION_PULL = _pywsman.EVT_ACTION_PULL

EVT_ACTION_GETSTATUS = _pywsman.EVT_ACTION_GETSTATUS

EVT_ACTION_UNSUBSCRIBE = _pywsman.EVT_ACTION_UNSUBSCRIBE

WSEVENT_UNSUBSCRIBE = _pywsman.WSEVENT_UNSUBSCRIBE

WSEVENT_UNSUBSCRIBE_RESP = _pywsman.WSEVENT_UNSUBSCRIBE_RESP

EVT_ACTION_SUBEND = _pywsman.EVT_ACTION_SUBEND

EVT_ACTION_RENEW = _pywsman.EVT_ACTION_RENEW

WSEVENT_RENEW = _pywsman.WSEVENT_RENEW

WSEVENT_RENEW_RESP = _pywsman.WSEVENT_RENEW_RESP

WSMAN_ACTION_EVENTS = _pywsman.WSMAN_ACTION_EVENTS

WSMAN_ACTION_HEARTBEAT = _pywsman.WSMAN_ACTION_HEARTBEAT

WSMAN_ACTION_DROPPEDEVENTS = _pywsman.WSMAN_ACTION_DROPPEDEVENTS

WSMAN_ACTION_ACK = _pywsman.WSMAN_ACTION_ACK

WSMAN_ACTION_EVENT = _pywsman.WSMAN_ACTION_EVENT

WSENUM_ACTION_FAULT = _pywsman.WSENUM_ACTION_FAULT

WSENUM_RENEW = _pywsman.WSENUM_RENEW

WSENUM_RENEW_RESP = _pywsman.WSENUM_RENEW_RESP

WSENUM_GET_STATUS = _pywsman.WSENUM_GET_STATUS

WSENUM_GET_STATUS_RESP = _pywsman.WSENUM_GET_STATUS_RESP

WSMAN_ACTION_FAULT = _pywsman.WSMAN_ACTION_FAULT

WSENUM_END_TO = _pywsman.WSENUM_END_TO

WSENUM_EXPIRES = _pywsman.WSENUM_EXPIRES

WSENUM_FILTER = _pywsman.WSENUM_FILTER

WSENUM_DIALECT = _pywsman.WSENUM_DIALECT

WSENUM_ENUMERATION_CONTEXT = _pywsman.WSENUM_ENUMERATION_CONTEXT

WSENUM_MAX_TIME = _pywsman.WSENUM_MAX_TIME

WSENUM_MAX_ELEMENTS = _pywsman.WSENUM_MAX_ELEMENTS

WSENUM_MAX_CHARACTERS = _pywsman.WSENUM_MAX_CHARACTERS

WSENUM_ITEMS = _pywsman.WSENUM_ITEMS

WSENUM_END_OF_SEQUENCE = _pywsman.WSENUM_END_OF_SEQUENCE

WSENUM_ENUMERATION_END = _pywsman.WSENUM_ENUMERATION_END

WSENUM_REASON = _pywsman.WSENUM_REASON

WSENUM_CODE = _pywsman.WSENUM_CODE

WSENUM_SOURCE_SHUTTING_DOWN = _pywsman.WSENUM_SOURCE_SHUTTING_DOWN

WSENUM_SOURCE_CANCELING = _pywsman.WSENUM_SOURCE_CANCELING

WSEVENT_DELIVERY = _pywsman.WSEVENT_DELIVERY

WSEVENT_NOTIFY_TO = _pywsman.WSEVENT_NOTIFY_TO

WSEVENT_ENDTO = _pywsman.WSEVENT_ENDTO

WSEVENT_EXPIRES = _pywsman.WSEVENT_EXPIRES

WSEVENT_DELIVERY_MODE = _pywsman.WSEVENT_DELIVERY_MODE

WSEVENT_SUBSCRIPTION_MANAGER = _pywsman.WSEVENT_SUBSCRIPTION_MANAGER

WSEVENT_IDENTIFIER = _pywsman.WSEVENT_IDENTIFIER

WSEVENT_FILTER = _pywsman.WSEVENT_FILTER

WSEVENT_DIALECT = _pywsman.WSEVENT_DIALECT

WSEVENT_ACTION_FAULT = _pywsman.WSEVENT_ACTION_FAULT

WSEVENT_DELIVERY_MODE_PUSH = _pywsman.WSEVENT_DELIVERY_MODE_PUSH

WSEVENT_DELIVERY_MODE_PUSHWITHACK = _pywsman.WSEVENT_DELIVERY_MODE_PUSHWITHACK

WSEVENT_DELIVERY_MODE_EVENTS = _pywsman.WSEVENT_DELIVERY_MODE_EVENTS

WSEVENT_DELIVERY_MODE_PULL = _pywsman.WSEVENT_DELIVERY_MODE_PULL

WSMB_ASSOCIATED_INSTANCES = _pywsman.WSMB_ASSOCIATED_INSTANCES

WSMB_ASSOCIATION_INSTANCES = _pywsman.WSMB_ASSOCIATION_INSTANCES

WSMB_OBJECT = _pywsman.WSMB_OBJECT

WSMB_ASSOCIATION_CLASS_NAME = _pywsman.WSMB_ASSOCIATION_CLASS_NAME

WSMB_RESULT_CLASS_NAME = _pywsman.WSMB_RESULT_CLASS_NAME

WSMB_ROLE = _pywsman.WSMB_ROLE

WSMB_RESULT_ROLE = _pywsman.WSMB_RESULT_ROLE

WSMB_INCLUDE_RESULT_PROPERTY = _pywsman.WSMB_INCLUDE_RESULT_PROPERTY

CIM_RESOURCE_NS_PREFIX = _pywsman.CIM_RESOURCE_NS_PREFIX

WSM_SYSTEM = _pywsman.WSM_SYSTEM

WSM_LOCALE = _pywsman.WSM_LOCALE

WSM_RESOURCE_URI = _pywsman.WSM_RESOURCE_URI

WSM_SELECTOR_SET = _pywsman.WSM_SELECTOR_SET

WSM_SELECTOR = _pywsman.WSM_SELECTOR

WSM_NAME = _pywsman.WSM_NAME

WSM_REQUEST_TOTAL = _pywsman.WSM_REQUEST_TOTAL

WSM_TOTAL_ESTIMATE = _pywsman.WSM_TOTAL_ESTIMATE

WSM_OPTIMIZE_ENUM = _pywsman.WSM_OPTIMIZE_ENUM

WSM_MAX_ELEMENTS = _pywsman.WSM_MAX_ELEMENTS

WSM_ENUM_EPR = _pywsman.WSM_ENUM_EPR

WSM_ENUM_OBJ_AND_EPR = _pywsman.WSM_ENUM_OBJ_AND_EPR

WSM_ENUM_MODE = _pywsman.WSM_ENUM_MODE

WSM_ITEM = _pywsman.WSM_ITEM

WSM_FRAGMENT_TRANSFER = _pywsman.WSM_FRAGMENT_TRANSFER

WSM_XML_FRAGMENT = _pywsman.WSM_XML_FRAGMENT

WSM_OPTION_SET = _pywsman.WSM_OPTION_SET

WSM_OPTION = _pywsman.WSM_OPTION

WSM_TOTAL = _pywsman.WSM_TOTAL

WSM_HEARTBEATS = _pywsman.WSM_HEARTBEATS

WSM_EVENTS = _pywsman.WSM_EVENTS

WSM_ACTION = _pywsman.WSM_ACTION

WSM_EVENT = _pywsman.WSM_EVENT

WSM_ACKREQUESTED = _pywsman.WSM_ACKREQUESTED

WSM_MAX_ENVELOPE_SIZE = _pywsman.WSM_MAX_ENVELOPE_SIZE

WSM_OPERATION_TIMEOUT = _pywsman.WSM_OPERATION_TIMEOUT

WSM_FAULT_SUBCODE = _pywsman.WSM_FAULT_SUBCODE

WSM_FILTER = _pywsman.WSM_FILTER

WSM_DIALECT = _pywsman.WSM_DIALECT

WSM_CONTENTCODING = _pywsman.WSM_CONTENTCODING

WSM_CONNECTIONRETRY = _pywsman.WSM_CONNECTIONRETRY

WSM_SENDBOOKMARKS = _pywsman.WSM_SENDBOOKMARKS

WSM_BOOKMARK = _pywsman.WSM_BOOKMARK

WSM_DROPPEDEVENTS = _pywsman.WSM_DROPPEDEVENTS

WSM_AUTH = _pywsman.WSM_AUTH

WSM_PROFILE = _pywsman.WSM_PROFILE

WSM_CERTIFICATETHUMBPRINT = _pywsman.WSM_CERTIFICATETHUMBPRINT

WSM_DEFAULTBOOKMARK = _pywsman.WSM_DEFAULTBOOKMARK

WXF_RESOURCE_CREATED = _pywsman.WXF_RESOURCE_CREATED

WSMB_POLYMORPHISM_MODE = _pywsman.WSMB_POLYMORPHISM_MODE

WSMB_INCLUDE_SUBCLASS_PROP = _pywsman.WSMB_INCLUDE_SUBCLASS_PROP

WSMB_EXCLUDE_SUBCLASS_PROP = _pywsman.WSMB_EXCLUDE_SUBCLASS_PROP

WSMB_NONE = _pywsman.WSMB_NONE

WSMB_DERIVED_REPRESENTATION = _pywsman.WSMB_DERIVED_REPRESENTATION

WSMB_ACTION_FAULT = _pywsman.WSMB_ACTION_FAULT

WSMB_SHOW_EXTENSION = _pywsman.WSMB_SHOW_EXTENSION

WSMB_EXCLUDE_NIL_PROPS = _pywsman.WSMB_EXCLUDE_NIL_PROPS

WSMANCAT_RESOURCE = _pywsman.WSMANCAT_RESOURCE

WSMANCAT_RESOURCE_URI = _pywsman.WSMANCAT_RESOURCE_URI

WSMANCAT_VERSION = _pywsman.WSMANCAT_VERSION

WSMANCAT_NOTES = _pywsman.WSMANCAT_NOTES

WSMANCAT_VENDOR = _pywsman.WSMANCAT_VENDOR

WSMANCAT_DISPLAY_NAME = _pywsman.WSMANCAT_DISPLAY_NAME

WSMANCAT_KEYWORDS = _pywsman.WSMANCAT_KEYWORDS

WSMANCAT_ACCESS = _pywsman.WSMANCAT_ACCESS

WSMANCAT_RELATIONSHIPS = _pywsman.WSMANCAT_RELATIONSHIPS

WSMANCAT_COMPLIANCE = _pywsman.WSMANCAT_COMPLIANCE

WSMANCAT_OPERATION = _pywsman.WSMANCAT_OPERATION

WSMANCAT_SELECTOR_SET = _pywsman.WSMANCAT_SELECTOR_SET

WSMANCAT_SELECTOR = _pywsman.WSMANCAT_SELECTOR

WSMANCAT_OPTION_SET = _pywsman.WSMANCAT_OPTION_SET

WSMANCAT_ACTION = _pywsman.WSMANCAT_ACTION

WSMANCAT_SELECTOR_SET_REF = _pywsman.WSMANCAT_SELECTOR_SET_REF

WSMANCAT_LOCATION = _pywsman.WSMANCAT_LOCATION

WSMANCAT_NAME = _pywsman.WSMANCAT_NAME

WSMANCAT_TYPE = _pywsman.WSMANCAT_TYPE

WSM_SELECTOR_FILTER_DIALECT = _pywsman.WSM_SELECTOR_FILTER_DIALECT

WSM_WQL_FILTER_DIALECT = _pywsman.WSM_WQL_FILTER_DIALECT

WSM_XPATH_FILTER_DIALECT = _pywsman.WSM_XPATH_FILTER_DIALECT

WSM_CQL_FILTER_DIALECT = _pywsman.WSM_CQL_FILTER_DIALECT

WSM_ASSOCIATION_FILTER_DIALECT = _pywsman.WSM_ASSOCIATION_FILTER_DIALECT

WSM_XPATH_EVENTROOT_FILTER = _pywsman.WSM_XPATH_EVENTROOT_FILTER

WSFW_RESPONSE_STR = _pywsman.WSFW_RESPONSE_STR

WSFW_INDOC = _pywsman.WSFW_INDOC

WSFW_ENUM_PREFIX = _pywsman.WSFW_ENUM_PREFIX

CIM_NAMESPACE_SELECTOR = _pywsman.CIM_NAMESPACE_SELECTOR

CIM_ALL_AVAILABLE_CLASSES = _pywsman.CIM_ALL_AVAILABLE_CLASSES

XML_NS_CIM_ALL_CLASS = _pywsman.XML_NS_CIM_ALL_CLASS

CIM_ACTION_ENUMERATE_CLASS_NAMES = _pywsman.CIM_ACTION_ENUMERATE_CLASS_NAMES

CIM_ACTION_ENUMERATE_INSTANCE_NAMES = _pywsman.CIM_ACTION_ENUMERATE_INSTANCE_NAMES

CIM_ACTION_ENUMERATE_CLASSES = _pywsman.CIM_ACTION_ENUMERATE_CLASSES

CIM_ACTION_GET_CLASS = _pywsman.CIM_ACTION_GET_CLASS

CIM_ACTION_DELETE_CLASS = _pywsman.CIM_ACTION_DELETE_CLASS

WST_ISSUEDTOKENS = _pywsman.WST_ISSUEDTOKENS

WST_REQUESTSECURITYTOKENRESPONSE = _pywsman.WST_REQUESTSECURITYTOKENRESPONSE

WST_TOKENTYPE = _pywsman.WST_TOKENTYPE

WST_REQUESTEDSECURITYTOKEN = _pywsman.WST_REQUESTEDSECURITYTOKEN

WSSE_USERNAMETOKEN = _pywsman.WSSE_USERNAMETOKEN

WSSE_USERNAME = _pywsman.WSSE_USERNAME

WSSE_PASSWORD = _pywsman.WSSE_PASSWORD

WSP_APPLIESTO = _pywsman.WSP_APPLIESTO

WST_USERNAMETOKEN = _pywsman.WST_USERNAMETOKEN

WST_CERTIFICATETHUMBPRINT = _pywsman.WST_CERTIFICATETHUMBPRINT

WSMAN_SECURITY_PROFILE_HTTP_BASIC = _pywsman.WSMAN_SECURITY_PROFILE_HTTP_BASIC

WSMAN_SECURITY_PROFILE_HTTP_DIGEST = _pywsman.WSMAN_SECURITY_PROFILE_HTTP_DIGEST

WSMAN_SECURITY_PROFILE_HTTPS_BASIC = _pywsman.WSMAN_SECURITY_PROFILE_HTTPS_BASIC

WSMAN_SECURITY_PROFILE_HTTPS_DIGEST = _pywsman.WSMAN_SECURITY_PROFILE_HTTPS_DIGEST

WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL = _pywsman.WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL

WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_BASIC = _pywsman.WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_BASIC

WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_DIGEST = _pywsman.WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_DIGEST

WSMAN_SECURITY_PROFILE_HTTPS_SPNEGO_KERBEROS = _pywsman.WSMAN_SECURITY_PROFILE_HTTPS_SPNEGO_KERBEROS

WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_SPNEGO_KERBEROS = _pywsman.WSMAN_SECURITY_PROFILE_HTTPS_MUTUAL_SPNEGO_KERBEROS

WSMAN_SECURITY_PROFILE_HTTP_SPNEGO_KERBEROS = _pywsman.WSMAN_SECURITY_PROFILE_HTTP_SPNEGO_KERBEROS

FLAG_NONE = _pywsman.FLAG_NONE

FLAG_ENUMERATION_COUNT_ESTIMATION = _pywsman.FLAG_ENUMERATION_COUNT_ESTIMATION

FLAG_ENUMERATION_OPTIMIZATION = _pywsman.FLAG_ENUMERATION_OPTIMIZATION

FLAG_ENUMERATION_ENUM_EPR = _pywsman.FLAG_ENUMERATION_ENUM_EPR

FLAG_ENUMERATION_ENUM_OBJ_AND_EPR = _pywsman.FLAG_ENUMERATION_ENUM_OBJ_AND_EPR

FLAG_DUMP_REQUEST = _pywsman.FLAG_DUMP_REQUEST

FLAG_INCLUDESUBCLASSPROPERTIES = _pywsman.FLAG_INCLUDESUBCLASSPROPERTIES

FLAG_EXCLUDESUBCLASSPROPERTIES = _pywsman.FLAG_EXCLUDESUBCLASSPROPERTIES

FLAG_POLYMORPHISM_NONE = _pywsman.FLAG_POLYMORPHISM_NONE

FLAG_MUND_MAX_ESIZE = _pywsman.FLAG_MUND_MAX_ESIZE

FLAG_MUND_LOCALE = _pywsman.FLAG_MUND_LOCALE

FLAG_MUND_OPTIONSET = _pywsman.FLAG_MUND_OPTIONSET

FLAG_MUND_FRAGMENT = _pywsman.FLAG_MUND_FRAGMENT

FLAG_CIM_EXTENSIONS = _pywsman.FLAG_CIM_EXTENSIONS

FLAG_CIM_REFERENCES = _pywsman.FLAG_CIM_REFERENCES

FLAG_CIM_ASSOCIATORS = _pywsman.FLAG_CIM_ASSOCIATORS

FLAG_EVENT_SENDBOOKMARK = _pywsman.FLAG_EVENT_SENDBOOKMARK

FLAG_CIM_SCHEMA_OPT = _pywsman.FLAG_CIM_SCHEMA_OPT

WSMAN_DELIVERY_PUSH = _pywsman.WSMAN_DELIVERY_PUSH

WSMAN_DELIVERY_PUSHWITHACK = _pywsman.WSMAN_DELIVERY_PUSHWITHACK

WSMAN_DELIVERY_EVENTS = _pywsman.WSMAN_DELIVERY_EVENTS

WSMAN_DELIVERY_PULL = _pywsman.WSMAN_DELIVERY_PULL

WS_NO_AUTH = _pywsman.WS_NO_AUTH

WS_BASIC_AUTH = _pywsman.WS_BASIC_AUTH

WS_DIGEST_AUTH = _pywsman.WS_DIGEST_AUTH

WS_PASS_AUTH = _pywsman.WS_PASS_AUTH

WS_NTLM_AUTH = _pywsman.WS_NTLM_AUTH

WS_GSSNEGOTIATE_AUTH = _pywsman.WS_GSSNEGOTIATE_AUTH

WS_MAX_AUTH = _pywsman.WS_MAX_AUTH

WSMAN_DELIVERY_SEC_AUTO = _pywsman.WSMAN_DELIVERY_SEC_AUTO

WSMAN_DELIVERY_SEC_HTTP_BASIC = _pywsman.WSMAN_DELIVERY_SEC_HTTP_BASIC

WSMAN_DELIVERY_SEC_HTTP_DIGEST = _pywsman.WSMAN_DELIVERY_SEC_HTTP_DIGEST

WSMAN_DELIVERY_SEC_HTTPS_BASIC = _pywsman.WSMAN_DELIVERY_SEC_HTTPS_BASIC

WSMAN_DELIVERY_SEC_HTTPS_DIGEST = _pywsman.WSMAN_DELIVERY_SEC_HTTPS_DIGEST

WSMAN_DELIVERY_SEC_HTTPS_MUTUAL = _pywsman.WSMAN_DELIVERY_SEC_HTTPS_MUTUAL

WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_BASIC = _pywsman.WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_BASIC

WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_DIGEST = _pywsman.WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_DIGEST

WSMAN_DELIVERY_SEC_HTTPS_SPNEGO_KERBEROS = _pywsman.WSMAN_DELIVERY_SEC_HTTPS_SPNEGO_KERBEROS

WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_SPNEGO_KERBEROS = _pywsman.WSMAN_DELIVERY_SEC_HTTPS_MUTUAL_SPNEGO_KERBEROS

WSMAN_DELIVERY_SEC_HTTP_SPNEGO_KERBEROS = _pywsman.WSMAN_DELIVERY_SEC_HTTP_SPNEGO_KERBEROS

class EndPointReference(object):
    r"""Proxy of C epr_t struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(EndPointReference self, char const * uri, char const * address) -> EndPointReference
        __init__(EndPointReference self, char const * uri) -> EndPointReference
        """
        _pywsman.EndPointReference_swiginit(self, _pywsman.new_EndPointReference(*args))
    __swig_destroy__ = _pywsman.delete_EndPointReference

    def add_selector(self, name, text):
        r"""add_selector(EndPointReference self, char const * name, char const * text)"""
        return _pywsman.EndPointReference_add_selector(self, name, text)

    def serialize(self, node, ns, epr_node_name, embedded):
        r"""serialize(EndPointReference self, XmlNode node, char const * ns, char const * epr_node_name, int embedded) -> int"""
        return _pywsman.EndPointReference_serialize(self, node, ns, epr_node_name, embedded)

    def cmp(self, epr2):
        r"""cmp(EndPointReference self, EndPointReference epr2) -> int"""
        return _pywsman.EndPointReference_cmp(self, epr2)

    def to_xml(self, ns=None, epr_node_name=None):
        r"""to_xml(EndPointReference self, char const * ns=None, char const * epr_node_name=None) -> char *"""
        return _pywsman.EndPointReference_to_xml(self, ns, epr_node_name)

    def string(self):
        r"""string(EndPointReference self) -> char *"""
        return _pywsman.EndPointReference_string(self)

    def selector_count(self):
        r"""selector_count(EndPointReference self) -> int"""
        return _pywsman.EndPointReference_selector_count(self)

    def resource_uri(self):
        r"""resource_uri(EndPointReference self) -> char *"""
        return _pywsman.EndPointReference_resource_uri(self)

    def selector(self, name):
        r"""selector(EndPointReference self, char const * name) -> char *"""
        return _pywsman.EndPointReference_selector(self, name)

    def selector_names(self):
        r"""selector_names(EndPointReference self) -> PyObject *"""
        return _pywsman.EndPointReference_selector_names(self)

    def classname(self):
        r"""classname(EndPointReference self) -> char *"""
        return _pywsman.EndPointReference_classname(self)

    def namespace(self):
        r"""namespace(EndPointReference self) -> char *"""
        return _pywsman.EndPointReference_namespace(self)

    def prefix(self):
        r"""prefix(EndPointReference self) -> char *"""
        return _pywsman.EndPointReference_prefix(self)

# Register EndPointReference in _pywsman:
_pywsman.EndPointReference_swigregister(EndPointReference)
class Filter(object):
    r"""Proxy of C filter_t struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    resultClass = property(_pywsman.Filter_resultClass_get, _pywsman.Filter_resultClass_set, doc=r"""resultClass : p.char""")
    assocClass = property(_pywsman.Filter_assocClass_get, _pywsman.Filter_assocClass_set, doc=r"""assocClass : p.char""")

    def __init__(self):
        r"""__init__(Filter self) -> Filter"""
        _pywsman.Filter_swiginit(self, _pywsman.new_Filter())
    __swig_destroy__ = _pywsman.delete_Filter

    def associators(self, epr, assocClass, resultClass, role, resultRole, resultProp, propNum):
        r"""associators(Filter self, EndPointReference epr, char const * assocClass, char const * resultClass, char const * role, char const * resultRole, char ** resultProp, int const propNum) -> int"""
        return _pywsman.Filter_associators(self, epr, assocClass, resultClass, role, resultRole, resultProp, propNum)

    def references(self, epr, assocClass, resultClass, role, resultRole, resultProp, propNum):
        r"""references(Filter self, EndPointReference epr, char const * assocClass, char const * resultClass, char const * role, char const * resultRole, char ** resultProp, int const propNum) -> int"""
        return _pywsman.Filter_references(self, epr, assocClass, resultClass, role, resultRole, resultProp, propNum)

    def simple(self, dialect, query):
        r"""simple(Filter self, char const * dialect, char const * query) -> int"""
        return _pywsman.Filter_simple(self, dialect, query)

    def xpath(self, query):
        r"""xpath(Filter self, char const * query) -> int"""
        return _pywsman.Filter_xpath(self, query)

    def cql(self, query):
        r"""cql(Filter self, char const * query) -> int"""
        return _pywsman.Filter_cql(self, query)

    def wql(self, query):
        r"""wql(Filter self, char const * query) -> int"""
        return _pywsman.Filter_wql(self, query)

# Register Filter in _pywsman:
_pywsman.Filter_swigregister(Filter)
FAULT_SENDER_CODE = _pywsman.FAULT_SENDER_CODE

FAULT_MUSTUNDERSTAND_CODE = _pywsman.FAULT_MUSTUNDERSTAND_CODE

FAULT_RECEIVER_CODE = _pywsman.FAULT_RECEIVER_CODE

FAULT_SENDER_CODE_NS = _pywsman.FAULT_SENDER_CODE_NS

FAULT_RECEIVER_CODE_NS = _pywsman.FAULT_RECEIVER_CODE_NS

FAULT_MUSTUNDERSTAND_CODE_NS = _pywsman.FAULT_MUSTUNDERSTAND_CODE_NS

WSMAN_RC_OK = _pywsman.WSMAN_RC_OK

WSMAN_ACCESS_DENIED = _pywsman.WSMAN_ACCESS_DENIED

WSA_ACTION_NOT_SUPPORTED = _pywsman.WSA_ACTION_NOT_SUPPORTED

WSMAN_ALREADY_EXISTS = _pywsman.WSMAN_ALREADY_EXISTS

WSEN_CANNOT_PROCESS_FILTER = _pywsman.WSEN_CANNOT_PROCESS_FILTER

WSMAN_CANNOT_PROCESS_FILTER = _pywsman.WSMAN_CANNOT_PROCESS_FILTER

WSMAN_CONCURRENCY = _pywsman.WSMAN_CONCURRENCY

WSE_DELIVERY_MODE_REQUESTED_UNAVAILABLE = _pywsman.WSE_DELIVERY_MODE_REQUESTED_UNAVAILABLE

WSMAN_DELIVERY_REFUSED = _pywsman.WSMAN_DELIVERY_REFUSED

WSA_DESTINATION_UNREACHABLE = _pywsman.WSA_DESTINATION_UNREACHABLE

WSMAN_ENCODING_LIMIT = _pywsman.WSMAN_ENCODING_LIMIT

WSA_ENDPOINT_UNAVAILABLE = _pywsman.WSA_ENDPOINT_UNAVAILABLE

WSMAN_EVENT_DELIVER_TO_UNUSABLE = _pywsman.WSMAN_EVENT_DELIVER_TO_UNUSABLE

WSE_EVENT_SOURCE_UNABLE_TO_PROCESS = _pywsman.WSE_EVENT_SOURCE_UNABLE_TO_PROCESS

WSEN_FILTER_DIALECT_REQUESTED_UNAVAILABLE = _pywsman.WSEN_FILTER_DIALECT_REQUESTED_UNAVAILABLE

WSE_FILTERING_NOT_SUPPORTED = _pywsman.WSE_FILTERING_NOT_SUPPORTED

WSEN_FILTERING_NOT_SUPPORTED = _pywsman.WSEN_FILTERING_NOT_SUPPORTED

WSE_FILTERING_REQUESTED_UNAVAILABLE = _pywsman.WSE_FILTERING_REQUESTED_UNAVAILABLE

WSMAN_FRAGMENT_DIALECT_NOT_SUPPORTED = _pywsman.WSMAN_FRAGMENT_DIALECT_NOT_SUPPORTED

WSMAN_INTERNAL_ERROR = _pywsman.WSMAN_INTERNAL_ERROR

WSMAN_INVALID_BOOKMARK = _pywsman.WSMAN_INVALID_BOOKMARK

WSEN_INVALID_ENUMERATION_CONTEXT = _pywsman.WSEN_INVALID_ENUMERATION_CONTEXT

WSE_INVALID_EXPIRATION_TIME = _pywsman.WSE_INVALID_EXPIRATION_TIME

WSEN_INVALID_EXPIRATION_TIME = _pywsman.WSEN_INVALID_EXPIRATION_TIME

WSE_INVALID_MESSAGE = _pywsman.WSE_INVALID_MESSAGE

WSA_INVALID_MESSAGE_INFORMATION_HEADER = _pywsman.WSA_INVALID_MESSAGE_INFORMATION_HEADER

WSMAN_INVALID_OPTIONS = _pywsman.WSMAN_INVALID_OPTIONS

WSMAN_INVALID_PARAMETER = _pywsman.WSMAN_INVALID_PARAMETER

WXF_INVALID_REPRESENTATION = _pywsman.WXF_INVALID_REPRESENTATION

WSMAN_INVALID_SELECTORS = _pywsman.WSMAN_INVALID_SELECTORS

WSA_MESSAGE_INFORMATION_HEADER_REQUIRED = _pywsman.WSA_MESSAGE_INFORMATION_HEADER_REQUIRED

WSMAN_NO_ACK = _pywsman.WSMAN_NO_ACK

WSMAN_QUOTA_LIMIT = _pywsman.WSMAN_QUOTA_LIMIT

WSMAN_SCHEMA_VALIDATION_ERROR = _pywsman.WSMAN_SCHEMA_VALIDATION_ERROR

WSEN_TIMED_OUT = _pywsman.WSEN_TIMED_OUT

WSMAN_TIMED_OUT = _pywsman.WSMAN_TIMED_OUT

WSE_UNABLE_TO_RENEW = _pywsman.WSE_UNABLE_TO_RENEW

WSE_UNSUPPORTED_EXPIRATION_TYPE = _pywsman.WSE_UNSUPPORTED_EXPIRATION_TYPE

WSEN_UNSUPPORTED_EXPIRATION_TYPE = _pywsman.WSEN_UNSUPPORTED_EXPIRATION_TYPE

WSMAN_UNSUPPORTED_FEATURE = _pywsman.WSMAN_UNSUPPORTED_FEATURE

SOAP_FAULT_VERSION_MISMATCH = _pywsman.SOAP_FAULT_VERSION_MISMATCH

SOAP_FAULT_MUSTUNDERSTAND = _pywsman.SOAP_FAULT_MUSTUNDERSTAND

WSMB_POLYMORPHISM_MODE_NOT_SUPPORTED = _pywsman.WSMB_POLYMORPHISM_MODE_NOT_SUPPORTED

WSMAN_UNKNOWN = _pywsman.WSMAN_UNKNOWN

WSMAN_DETAIL_OK = _pywsman.WSMAN_DETAIL_OK

WSMAN_DETAIL_ACK = _pywsman.WSMAN_DETAIL_ACK

WSMAN_DETAIL_ACTION_MISMATCH = _pywsman.WSMAN_DETAIL_ACTION_MISMATCH

WSMAN_DETAIL_ALREADY_EXISTS = _pywsman.WSMAN_DETAIL_ALREADY_EXISTS

WSMAN_DETAIL_AMBIGUOUS_SELECTORS = _pywsman.WSMAN_DETAIL_AMBIGUOUS_SELECTORS

WSMAN_DETAIL_ASYNCHRONOUS_REQUEST = _pywsman.WSMAN_DETAIL_ASYNCHRONOUS_REQUEST

WSMAN_DETAIL_ADDRESSING_MODE = _pywsman.WSMAN_DETAIL_ADDRESSING_MODE

WSMAN_DETAIL_AUTHERIZATION_MODE = _pywsman.WSMAN_DETAIL_AUTHERIZATION_MODE

WSMAN_DETAIL_BOOKMARKS = _pywsman.WSMAN_DETAIL_BOOKMARKS

WSMAN_DETAIL_CHARECHTER_SET = _pywsman.WSMAN_DETAIL_CHARECHTER_SET

WSMAN_DETAIL_DELIVERY_RETRIES = _pywsman.WSMAN_DETAIL_DELIVERY_RETRIES

WSMAN_DETAIL_DUPLICATE_SELECTORS = _pywsman.WSMAN_DETAIL_DUPLICATE_SELECTORS

WSMAN_DETAIL_ENCODING_TYPE = _pywsman.WSMAN_DETAIL_ENCODING_TYPE

WSMAN_DETAIL_ENUMERATION_MODE = _pywsman.WSMAN_DETAIL_ENUMERATION_MODE

WSMAN_DETAIL_EXPIRATION_TIME = _pywsman.WSMAN_DETAIL_EXPIRATION_TIME

WSMAN_DETAIL_EXPIRED = _pywsman.WSMAN_DETAIL_EXPIRED

WSMAN_DETAIL_FILTERING_REQUIRED = _pywsman.WSMAN_DETAIL_FILTERING_REQUIRED

WSMAN_DETAIL_FORMAT_MISMATCH = _pywsman.WSMAN_DETAIL_FORMAT_MISMATCH

WSMAN_DETAIL_FORMAT_SECURITY_TOKEN = _pywsman.WSMAN_DETAIL_FORMAT_SECURITY_TOKEN

WSMAN_DETAIL_FRAGMENT_LEVEL_ACCESS = _pywsman.WSMAN_DETAIL_FRAGMENT_LEVEL_ACCESS

WSMAN_DETAIL_HEARTBEATS = _pywsman.WSMAN_DETAIL_HEARTBEATS

WSMAN_DETAIL_INSECURE_ADDRESS = _pywsman.WSMAN_DETAIL_INSECURE_ADDRESS

WSMAN_DETAIL_INSUFFICIENT_SELECTORS = _pywsman.WSMAN_DETAIL_INSUFFICIENT_SELECTORS

WSMAN_DETAIL_INVALID = _pywsman.WSMAN_DETAIL_INVALID

WSMAN_DETAIL_INVALID_ADDRESS = _pywsman.WSMAN_DETAIL_INVALID_ADDRESS

WSMAN_DETAIL_INVALID_FORMAT = _pywsman.WSMAN_DETAIL_INVALID_FORMAT

WSMAN_DETAIL_INVALID_FRAGMENT = _pywsman.WSMAN_DETAIL_INVALID_FRAGMENT

WSMAN_DETAIL_INVALID_NAME = _pywsman.WSMAN_DETAIL_INVALID_NAME

WSMAN_DETAIL_INVALID_NAMESPACE = _pywsman.WSMAN_DETAIL_INVALID_NAMESPACE

WSMAN_DETAIL_INVALID_RESOURCEURI = _pywsman.WSMAN_DETAIL_INVALID_RESOURCEURI

WSMAN_DETAIL_INVALID_SELECTOR_ASSIGNMENT = _pywsman.WSMAN_DETAIL_INVALID_SELECTOR_ASSIGNMENT

WSMAN_DETAIL_INVALID_SYSTEM = _pywsman.WSMAN_DETAIL_INVALID_SYSTEM

WSMAN_DETAIL_INVALID_TIMEOUT = _pywsman.WSMAN_DETAIL_INVALID_TIMEOUT

WSMAN_DETAIL_INVALID_VALUE = _pywsman.WSMAN_DETAIL_INVALID_VALUE

WSMAN_DETAIL_INVALID_VALUES = _pywsman.WSMAN_DETAIL_INVALID_VALUES

WSMAN_DETAIL_LOCALE = _pywsman.WSMAN_DETAIL_LOCALE

WSMAN_DETAIL_MAX_ELEMENTS = _pywsman.WSMAN_DETAIL_MAX_ELEMENTS

WSMAN_DETAIL_MAX_ENVELOPE_POLICY = _pywsman.WSMAN_DETAIL_MAX_ENVELOPE_POLICY

WSMAN_DETAIL_MAX_ENVELOPE_SIZE = _pywsman.WSMAN_DETAIL_MAX_ENVELOPE_SIZE

WSMAN_DETAIL_MAX_TIME = _pywsman.WSMAN_DETAIL_MAX_TIME

WSMAN_DETAIL_MINIMUM_ENVELOPE_LIMIT = _pywsman.WSMAN_DETAIL_MINIMUM_ENVELOPE_LIMIT

WSMAN_DETAIL_MISSING_VALUES = _pywsman.WSMAN_DETAIL_MISSING_VALUES

WSMAN_DETAIL_NOT_SUPPORTED = _pywsman.WSMAN_DETAIL_NOT_SUPPORTED

WSMAN_DETAIL_OPERATION_TIMEOUT = _pywsman.WSMAN_DETAIL_OPERATION_TIMEOUT

WSMAN_DETAIL_OPTION_LIMIT = _pywsman.WSMAN_DETAIL_OPTION_LIMIT

WSMAN_DETAIL_OPTION_SET = _pywsman.WSMAN_DETAIL_OPTION_SET

WSMAN_DETAIL_READ_ONLY = _pywsman.WSMAN_DETAIL_READ_ONLY

WSMAN_DETAIL_RESOURCE_OFFLINE = _pywsman.WSMAN_DETAIL_RESOURCE_OFFLINE

WSMAN_DETAIL_RENAME = _pywsman.WSMAN_DETAIL_RENAME

WSMAN_DETAIL_SELECTOR_LIMIT = _pywsman.WSMAN_DETAIL_SELECTOR_LIMIT

WSMAN_DETAIL_SERVICE_ENVELOPE_LIMIT = _pywsman.WSMAN_DETAIL_SERVICE_ENVELOPE_LIMIT

WSMAN_DETAIL_TARGET_ALREADY_EXISTS = _pywsman.WSMAN_DETAIL_TARGET_ALREADY_EXISTS

WSMAN_DETAIL_TYPE_MISMATCH = _pywsman.WSMAN_DETAIL_TYPE_MISMATCH

WSMAN_DETAIL_UNEXPECTED_SELECTORS = _pywsman.WSMAN_DETAIL_UNEXPECTED_SELECTORS

WSMAN_DETAIL_UNREPORTABLE_SUCCESS = _pywsman.WSMAN_DETAIL_UNREPORTABLE_SUCCESS

WSMAN_DETAIL_UNUSABLE_ADDRESS = _pywsman.WSMAN_DETAIL_UNUSABLE_ADDRESS

WSMAN_DETAIL_URI_LIMIT_EXCEEDED = _pywsman.WSMAN_DETAIL_URI_LIMIT_EXCEEDED

WSMAN_DETAIL_WHITESPACE = _pywsman.WSMAN_DETAIL_WHITESPACE

WSA_DETAIL_DUPLICATE_MESSAGE_ID = _pywsman.WSA_DETAIL_DUPLICATE_MESSAGE_ID

SOAP_DETAIL_HEADER_NOT_UNDERSTOOD = _pywsman.SOAP_DETAIL_HEADER_NOT_UNDERSTOOD

WST_DETAIL_UNSUPPORTED_TOKENTYPE = _pywsman.WST_DETAIL_UNSUPPORTED_TOKENTYPE

WSP_DETAIL_INVALID_EPR = _pywsman.WSP_DETAIL_INVALID_EPR

OWSMAN_DETAIL_ENDPOINT_ERROR = _pywsman.OWSMAN_DETAIL_ENDPOINT_ERROR

OWSMAN_NO_DETAILS = _pywsman.OWSMAN_NO_DETAILS

OWSMAN_SYSTEM_ERROR = _pywsman.OWSMAN_SYSTEM_ERROR

WSMAN_STATUS_NONE = _pywsman.WSMAN_STATUS_NONE

WSMAN_STATUS_CANCELLED = _pywsman.WSMAN_STATUS_CANCELLED

WSMAN_STATUS_CANT_RESOLVE = _pywsman.WSMAN_STATUS_CANT_RESOLVE

WSMAN_STATUS_CANT_RESOLVE_PROXY = _pywsman.WSMAN_STATUS_CANT_RESOLVE_PROXY

WSMAN_STATUS_CANT_CONNECT = _pywsman.WSMAN_STATUS_CANT_CONNECT

WSMAN_STATUS_CANT_CONNECT_PROXY = _pywsman.WSMAN_STATUS_CANT_CONNECT_PROXY

WSMAN_STATUS_SSL_FAILED = _pywsman.WSMAN_STATUS_SSL_FAILED

WSMAN_STATUS_IO_ERROR = _pywsman.WSMAN_STATUS_IO_ERROR

WSMAN_STATUS_MALFORMED = _pywsman.WSMAN_STATUS_MALFORMED

WSMAN_STATUS_TRY_AGAIN = _pywsman.WSMAN_STATUS_TRY_AGAIN

WSMAN_STATUS_CONTINUE = _pywsman.WSMAN_STATUS_CONTINUE

WSMAN_STATUS_SWITCHING_PROTOCOLS = _pywsman.WSMAN_STATUS_SWITCHING_PROTOCOLS

WSMAN_STATUS_PROCESSING = _pywsman.WSMAN_STATUS_PROCESSING

WSMAN_STATUS_OK = _pywsman.WSMAN_STATUS_OK

WSMAN_STATUS_CREATED = _pywsman.WSMAN_STATUS_CREATED

WSMAN_STATUS_ACCEPTED = _pywsman.WSMAN_STATUS_ACCEPTED

WSMAN_STATUS_NON_AUTHORITATIVE = _pywsman.WSMAN_STATUS_NON_AUTHORITATIVE

WSMAN_STATUS_NO_CONTENT = _pywsman.WSMAN_STATUS_NO_CONTENT

WSMAN_STATUS_RESET_CONTENT = _pywsman.WSMAN_STATUS_RESET_CONTENT

WSMAN_STATUS_PARTIAL_CONTENT = _pywsman.WSMAN_STATUS_PARTIAL_CONTENT

WSMAN_STATUS_MULTI_STATUS = _pywsman.WSMAN_STATUS_MULTI_STATUS

WSMAN_STATUS_MULTIPLE_CHOICES = _pywsman.WSMAN_STATUS_MULTIPLE_CHOICES

WSMAN_STATUS_MOVED_PERMANENTLY = _pywsman.WSMAN_STATUS_MOVED_PERMANENTLY

WSMAN_STATUS_FOUND = _pywsman.WSMAN_STATUS_FOUND

WSMAN_STATUS_MOVED_TEMPORARILY = _pywsman.WSMAN_STATUS_MOVED_TEMPORARILY

WSMAN_STATUS_SEE_OTHER = _pywsman.WSMAN_STATUS_SEE_OTHER

WSMAN_STATUS_NOT_MODIFIED = _pywsman.WSMAN_STATUS_NOT_MODIFIED

WSMAN_STATUS_USE_PROXY = _pywsman.WSMAN_STATUS_USE_PROXY

WSMAN_STATUS_NOT_APPEARING_IN_THIS_PROTOCOL = _pywsman.WSMAN_STATUS_NOT_APPEARING_IN_THIS_PROTOCOL

WSMAN_STATUS_TEMPORARY_REDIRECT = _pywsman.WSMAN_STATUS_TEMPORARY_REDIRECT

WSMAN_STATUS_BAD_REQUEST = _pywsman.WSMAN_STATUS_BAD_REQUEST

WSMAN_STATUS_UNAUTHORIZED = _pywsman.WSMAN_STATUS_UNAUTHORIZED

WSMAN_STATUS_PAYMENT_REQUIRED = _pywsman.WSMAN_STATUS_PAYMENT_REQUIRED

WSMAN_STATUS_FORBIDDEN = _pywsman.WSMAN_STATUS_FORBIDDEN

WSMAN_STATUS_NOT_FOUND = _pywsman.WSMAN_STATUS_NOT_FOUND

WSMAN_STATUS_METHOD_NOT_ALLOWED = _pywsman.WSMAN_STATUS_METHOD_NOT_ALLOWED

WSMAN_STATUS_NOT_ACCEPTABLE = _pywsman.WSMAN_STATUS_NOT_ACCEPTABLE

WSMAN_STATUS_PROXY_AUTHENTICATION_REQUIRED = _pywsman.WSMAN_STATUS_PROXY_AUTHENTICATION_REQUIRED

WSMAN_STATUS_PROXY_UNAUTHORIZED = _pywsman.WSMAN_STATUS_PROXY_UNAUTHORIZED

WSMAN_STATUS_REQUEST_TIMEOUT = _pywsman.WSMAN_STATUS_REQUEST_TIMEOUT

WSMAN_STATUS_CONFLICT = _pywsman.WSMAN_STATUS_CONFLICT

WSMAN_STATUS_GONE = _pywsman.WSMAN_STATUS_GONE

WSMAN_STATUS_LENGTH_REQUIRED = _pywsman.WSMAN_STATUS_LENGTH_REQUIRED

WSMAN_STATUS_PRECONDITION_FAILED = _pywsman.WSMAN_STATUS_PRECONDITION_FAILED

WSMAN_STATUS_REQUEST_ENTITY_TOO_LARGE = _pywsman.WSMAN_STATUS_REQUEST_ENTITY_TOO_LARGE

WSMAN_STATUS_REQUEST_URI_TOO_LONG = _pywsman.WSMAN_STATUS_REQUEST_URI_TOO_LONG

WSMAN_STATUS_UNSUPPORTED_MEDIA_TYPE = _pywsman.WSMAN_STATUS_UNSUPPORTED_MEDIA_TYPE

WSMAN_STATUS_REQUESTED_RANGE_NOT_SATISFIABLE = _pywsman.WSMAN_STATUS_REQUESTED_RANGE_NOT_SATISFIABLE

WSMAN_STATUS_INVALID_RANGE = _pywsman.WSMAN_STATUS_INVALID_RANGE

WSMAN_STATUS_EXPECTATION_FAILED = _pywsman.WSMAN_STATUS_EXPECTATION_FAILED

WSMAN_STATUS_UNPROCESSABLE_ENTITY = _pywsman.WSMAN_STATUS_UNPROCESSABLE_ENTITY

WSMAN_STATUS_LOCKED = _pywsman.WSMAN_STATUS_LOCKED

WSMAN_STATUS_FAILED_DEPENDENCY = _pywsman.WSMAN_STATUS_FAILED_DEPENDENCY

WSMAN_STATUS_INTERNAL_SERVER_ERROR = _pywsman.WSMAN_STATUS_INTERNAL_SERVER_ERROR

WSMAN_STATUS_NOT_IMPLEMENTED = _pywsman.WSMAN_STATUS_NOT_IMPLEMENTED

WSMAN_STATUS_BAD_GATEWAY = _pywsman.WSMAN_STATUS_BAD_GATEWAY

WSMAN_STATUS_SERVICE_UNAVAILABLE = _pywsman.WSMAN_STATUS_SERVICE_UNAVAILABLE

WSMAN_STATUS_GATEWAY_TIMEOUT = _pywsman.WSMAN_STATUS_GATEWAY_TIMEOUT

WSMAN_STATUS_HTTP_VERSION_NOT_SUPPORTED = _pywsman.WSMAN_STATUS_HTTP_VERSION_NOT_SUPPORTED

WSMAN_STATUS_INSUFFICIENT_STORAGE = _pywsman.WSMAN_STATUS_INSUFFICIENT_STORAGE

WSMAN_STATUS_NOT_EXTENDED = _pywsman.WSMAN_STATUS_NOT_EXTENDED

class EnumerateInfo(object):
    r"""Proxy of C __WsEnumerateInfo struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    __swig_destroy__ = _pywsman.delete_EnumerateInfo

    def max_items(self):
        r"""max_items(EnumerateInfo self) -> int"""
        return _pywsman.EnumerateInfo_max_items(self)

    def set_max_items(self, mi):
        r"""set_max_items(EnumerateInfo self, int mi)"""
        return _pywsman.EnumerateInfo_set_max_items(self, mi)

    def flags(self):
        r"""flags(EnumerateInfo self) -> int"""
        return _pywsman.EnumerateInfo_flags(self)

    def epr_to(self):
        r"""epr_to(EnumerateInfo self) -> char const *"""
        return _pywsman.EnumerateInfo_epr_to(self)

    def epr_uri(self):
        r"""epr_uri(EnumerateInfo self) -> char const *"""
        return _pywsman.EnumerateInfo_epr_uri(self)

    def encoding(self):
        r"""encoding(EnumerateInfo self) -> char const *"""
        return _pywsman.EnumerateInfo_encoding(self)

    def filter(self):
        r"""filter(EnumerateInfo self) -> Filter"""
        return _pywsman.EnumerateInfo_filter(self)

    def index(self):
        r"""index(EnumerateInfo self) -> int"""
        return _pywsman.EnumerateInfo_index(self)

    def set_index(self, i):
        r"""set_index(EnumerateInfo self, int i)"""
        return _pywsman.EnumerateInfo_set_index(self, i)

    def total_items(self):
        r"""total_items(EnumerateInfo self) -> int"""
        return _pywsman.EnumerateInfo_total_items(self)

    def set_total_items(self, i):
        r"""set_total_items(EnumerateInfo self, int i)"""
        return _pywsman.EnumerateInfo_set_total_items(self, i)

    def pull_result(self):
        r"""pull_result(EnumerateInfo self) -> XmlDoc"""
        return _pywsman.EnumerateInfo_pull_result(self)

    def set_pull_result(self, result):
        r"""set_pull_result(EnumerateInfo self, XmlDoc result)"""
        return _pywsman.EnumerateInfo_set_pull_result(self, result)

# Register EnumerateInfo in _pywsman:
_pywsman.EnumerateInfo_swigregister(EnumerateInfo)
class SoapOp(object):
    r"""Proxy of C __SoapOp struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def indoc(self):
        r"""indoc(SoapOp self) -> XmlDoc"""
        return _pywsman.SoapOp_indoc(self)

    def set_indoc(self, doc):
        r"""set_indoc(SoapOp self, XmlDoc doc)"""
        return _pywsman.SoapOp_set_indoc(self, doc)

    def outdoc(self):
        r"""outdoc(SoapOp self) -> XmlDoc"""
        return _pywsman.SoapOp_outdoc(self)

    def set_outdoc(self, doc):
        r"""set_outdoc(SoapOp self, XmlDoc doc)"""
        return _pywsman.SoapOp_set_outdoc(self, doc)

    def soap(self):
        r"""soap(SoapOp self) -> Soap"""
        return _pywsman.SoapOp_soap(self)

    def msg(self):
        r"""msg(SoapOp self) -> WsmanMessage *"""
        return _pywsman.SoapOp_msg(self)

    def maxsize(self):
        r"""maxsize(SoapOp self) -> unsigned long"""
        return _pywsman.SoapOp_maxsize(self)

# Register SoapOp in _pywsman:
_pywsman.SoapOp_swigregister(SoapOp)
class Soap(object):
    r"""Proxy of C __Soap struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    __swig_destroy__ = _pywsman.delete_Soap

    def create_context(self):
        r"""create_context(Soap self) -> Context"""
        return _pywsman.Soap_create_context(self)

    def context(self):
        r"""context(Soap self) -> Context"""
        return _pywsman.Soap_context(self)

    def create_ep_context(self, doc):
        r"""create_ep_context(Soap self, XmlDoc doc) -> Context"""
        return _pywsman.Soap_create_ep_context(self, doc)

# Register Soap in _pywsman:
_pywsman.Soap_swigregister(Soap)
class Context(object):
    r"""Proxy of C _WS_CONTEXT struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    __swig_destroy__ = _pywsman.delete_Context

    def indoc(self):
        r"""indoc(Context self) -> XmlDoc"""
        return _pywsman.Context_indoc(self)

    def runtime(self):
        r"""runtime(Context self) -> Soap"""
        return _pywsman.Context_runtime(self)

    def set_enumIdleTimeout(self, timeout):
        r"""set_enumIdleTimeout(Context self, unsigned long timeout)"""
        return _pywsman.Context_set_enumIdleTimeout(self, timeout)

    def classname(self):
        r"""classname(Context self) -> char const *"""
        return _pywsman.Context_classname(self)

    def method(self):
        r"""method(Context self) -> char const *"""
        return _pywsman.Context_method(self)

    def method_args(self, resource_uri):
        r"""method_args(Context self, char const * resource_uri) -> hash_t *"""
        return _pywsman.Context_method_args(self, resource_uri)

    def max_elements(self, doc=None):
        r"""max_elements(Context self, XmlDoc doc=None) -> int"""
        return _pywsman.Context_max_elements(self, doc)

    def max_envelope_size(self, doc=None):
        r"""max_envelope_size(Context self, XmlDoc doc=None) -> unsigned long"""
        return _pywsman.Context_max_envelope_size(self, doc)

    def fragment_string(self, doc=None):
        r"""fragment_string(Context self, XmlDoc doc=None) -> char const *"""
        return _pywsman.Context_fragment_string(self, doc)

    def selector(self, doc, name, index):
        r"""selector(Context self, XmlDoc doc, char const * name, int index) -> char const *"""
        return _pywsman.Context_selector(self, doc, name, index)

    def selectors_from_epr(self, epr_node):
        r"""selectors_from_epr(Context self, XmlNode epr_node) -> hash_t *"""
        return _pywsman.Context_selectors_from_epr(self, epr_node)

    def selectors(self, doc=None):
        r"""selectors(Context self, XmlDoc doc=None) -> hash_t *"""
        return _pywsman.Context_selectors(self, doc)

    def selectors_from_filter(self, doc=None):
        r"""selectors_from_filter(Context self, XmlDoc doc=None) -> hash_t *"""
        return _pywsman.Context_selectors_from_filter(self, doc)

    def action(self, doc=None):
        r"""action(Context self, XmlDoc doc=None) -> char const *"""
        return _pywsman.Context_action(self, doc)

    def resource_uri(self, doc=None):
        r"""resource_uri(Context self, XmlDoc doc=None) -> char const *"""
        return _pywsman.Context_resource_uri(self, doc)

    def option_set(self, doc, op):
        r"""option_set(Context self, XmlDoc doc, char const * op) -> char const *"""
        return _pywsman.Context_option_set(self, doc, op)

    def parse_enum_request(self, enumInfo):
        r"""parse_enum_request(Context self, WsEnumerateInfo * enumInfo) -> int"""
        return _pywsman.Context_parse_enum_request(self, enumInfo)

# Register Context in _pywsman:
_pywsman.Context_swigregister(Context)
class Status(object):
    r"""Proxy of C _WsmanStatus struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, code=0, detail=0, msg=None):
        r"""__init__(Status self, int code=0, int detail=0, char const * msg=None) -> Status"""
        _pywsman.Status_swiginit(self, _pywsman.new_Status(code, detail, msg))
    __swig_destroy__ = _pywsman.delete_Status

    def to_s(self):
        r"""to_s(Status self) -> char const *"""
        return _pywsman.Status_to_s(self)

    def set_code(self, code):
        r"""set_code(Status self, int code)"""
        return _pywsman.Status_set_code(self, code)

    def code(self):
        r"""code(Status self) -> int"""
        return _pywsman.Status_code(self)

    def set_detail(self, detail):
        r"""set_detail(Status self, int detail)"""
        return _pywsman.Status_set_detail(self, detail)

    def detail(self):
        r"""detail(Status self) -> int"""
        return _pywsman.Status_detail(self)

    def set_msg(self, msg):
        r"""set_msg(Status self, char const * msg)"""
        return _pywsman.Status_set_msg(self, msg)

    def msg(self):
        r"""msg(Status self) -> char const *"""
        return _pywsman.Status_msg(self)

    def generate_fault(self, doc):
        r"""generate_fault(Status self, XmlDoc doc) -> XmlDoc"""
        return _pywsman.Status_generate_fault(self, doc)

# Register Status in _pywsman:
_pywsman.Status_swigregister(Status)
class Fault(object):
    r"""Proxy of C _WsManFault struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, doc):
        r"""__init__(Fault self, XmlDoc doc) -> Fault"""
        _pywsman.Fault_swiginit(self, _pywsman.new_Fault(doc))
    __swig_destroy__ = _pywsman.delete_Fault

    def code(self):
        r"""code(Fault self) -> char const *"""
        return _pywsman.Fault_code(self)

    def subcode(self):
        r"""subcode(Fault self) -> char const *"""
        return _pywsman.Fault_subcode(self)

    def reason(self):
        r"""reason(Fault self) -> char const *"""
        return _pywsman.Fault_reason(self)

    def detail(self):
        r"""detail(Fault self) -> char const *"""
        return _pywsman.Fault_detail(self)

# Register Fault in _pywsman:
_pywsman.Fault_swigregister(Fault)
class Transport(object):
    r"""Proxy of C _WsManTransport struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def is_auth_method(self, method):
        r"""is_auth_method(Transport self, int method) -> int"""
        return _pywsman.Transport_is_auth_method(self, method)

    def close(self):
        r"""close(Transport self)"""
        return _pywsman.Transport_close(self)

    def set_agent(self, agent):
        r"""set_agent(Transport self, char const * agent)"""
        return _pywsman.Transport_set_agent(self, agent)

    def agent(self):
        r"""agent(Transport self) -> char *"""
        return _pywsman.Transport_agent(self)

    def get_username(self):
        r"""get_username(Transport self) -> char *"""
        return _pywsman.Transport_get_username(self)

    def set_username(self, user_name):
        r"""set_username(Transport self, char * user_name)"""
        return _pywsman.Transport_set_username(self, user_name)

    def get_password(self):
        r"""get_password(Transport self) -> char *"""
        return _pywsman.Transport_get_password(self)

    def set_password(self, password):
        r"""set_password(Transport self, char * password)"""
        return _pywsman.Transport_set_password(self, password)

    def get_proxy_username(self):
        r"""get_proxy_username(Transport self) -> char *"""
        return _pywsman.Transport_get_proxy_username(self)

    def set_proxy_username(self, proxy_username):
        r"""set_proxy_username(Transport self, char * proxy_username)"""
        return _pywsman.Transport_set_proxy_username(self, proxy_username)

    def get_proxy_password(self):
        r"""get_proxy_password(Transport self) -> char *"""
        return _pywsman.Transport_get_proxy_password(self)

    def set_proxy_password(self, proxy_password):
        r"""set_proxy_password(Transport self, char * proxy_password)"""
        return _pywsman.Transport_set_proxy_password(self, proxy_password)

    def set_auth_method(self, am):
        r"""set_auth_method(Transport self, char const * am)"""
        return _pywsman.Transport_set_auth_method(self, am)

    def auth_method(self):
        r"""auth_method(Transport self) -> char *"""
        return _pywsman.Transport_auth_method(self)

    @staticmethod
    def auth_name(auth):
        r"""auth_name(int auth) -> char const *"""
        return _pywsman.Transport_auth_name(auth)

    def auth_value(self):
        r"""auth_value(Transport self) -> int"""
        return _pywsman.Transport_auth_value(self)

    @staticmethod
    def error_string(err):
        r"""error_string(int err) -> char *"""
        return _pywsman.Transport_error_string(err)

    def set_timeout(self, timeout):
        r"""set_timeout(Transport self, unsigned long timeout)"""
        return _pywsman.Transport_set_timeout(self, timeout)

    def timeout(self):
        r"""timeout(Transport self) -> unsigned long"""
        return _pywsman.Transport_timeout(self)

    def set_verify_peer(self, value):
        r"""set_verify_peer(Transport self, unsigned int value)"""
        return _pywsman.Transport_set_verify_peer(self, value)

    def verify_peer(self):
        r"""verify_peer(Transport self) -> unsigned int"""
        return _pywsman.Transport_verify_peer(self)

    def set_verify_host(self, value):
        r"""set_verify_host(Transport self, unsigned int value)"""
        return _pywsman.Transport_set_verify_host(self, value)

    def verify_host(self):
        r"""verify_host(Transport self) -> unsigned int"""
        return _pywsman.Transport_verify_host(self)

    def set_proxy(self, proxy):
        r"""set_proxy(Transport self, char const * proxy)"""
        return _pywsman.Transport_set_proxy(self, proxy)

    def proxy(self):
        r"""proxy(Transport self) -> char *"""
        return _pywsman.Transport_proxy(self)

    def set_proxyauth(self, pauth):
        r"""set_proxyauth(Transport self, char const * pauth)"""
        return _pywsman.Transport_set_proxyauth(self, pauth)

    def proxyauth(self):
        r"""proxyauth(Transport self) -> char *"""
        return _pywsman.Transport_proxyauth(self)

    def set_cainfo(self, cainfo):
        r"""set_cainfo(Transport self, char const * cainfo)"""
        return _pywsman.Transport_set_cainfo(self, cainfo)

    def cainfo(self):
        r"""cainfo(Transport self) -> char *"""
        return _pywsman.Transport_cainfo(self)

    def set_certhumbprint(self, arg):
        r"""set_certhumbprint(Transport self, char const * arg)"""
        return _pywsman.Transport_set_certhumbprint(self, arg)

    def certhumbprint(self):
        r"""certhumbprint(Transport self) -> char *"""
        return _pywsman.Transport_certhumbprint(self)

    def set_capath(self, capath):
        r"""set_capath(Transport self, char const * capath)"""
        return _pywsman.Transport_set_capath(self, capath)

    def capath(self):
        r"""capath(Transport self) -> char *"""
        return _pywsman.Transport_capath(self)

    def set_caoid(self, oid):
        r"""set_caoid(Transport self, char const * oid)"""
        return _pywsman.Transport_set_caoid(self, oid)

    def caoid(self):
        r"""caoid(Transport self) -> char *"""
        return _pywsman.Transport_caoid(self)

    def set_cert(self, cert):
        r"""set_cert(Transport self, char const * cert)"""
        return _pywsman.Transport_set_cert(self, cert)

    def cert(self):
        r"""cert(Transport self) -> char *"""
        return _pywsman.Transport_cert(self)

    def set_key(self, key):
        r"""set_key(Transport self, char const * key)"""
        return _pywsman.Transport_set_key(self, key)

    def key(self):
        r"""key(Transport self) -> char *"""
        return _pywsman.Transport_key(self)

# Register Transport in _pywsman:
_pywsman.Transport_swigregister(Transport)
NO_AUTH = _pywsman.NO_AUTH

BASIC_AUTH = _pywsman.BASIC_AUTH

DIGEST_AUTH = _pywsman.DIGEST_AUTH

PASS_AUTH = _pywsman.PASS_AUTH

NTLM_AUTH = _pywsman.NTLM_AUTH

GSSNEGOTIATE_AUTH = _pywsman.GSSNEGOTIATE_AUTH

NO_AUTH_STR = _pywsman.NO_AUTH_STR

BASIC_AUTH_STR = _pywsman.BASIC_AUTH_STR

DIGEST_AUTH_STR = _pywsman.DIGEST_AUTH_STR

PASS_AUTH_STR = _pywsman.PASS_AUTH_STR

NTLM_AUTH_STR = _pywsman.NTLM_AUTH_STR

GSSNEGOTIATE_AUTH_STR = _pywsman.GSSNEGOTIATE_AUTH_STR


TRUE = _pywsman.TRUE

FALSE = _pywsman.FALSE

DEFAULT_USER_AGENT = _pywsman.DEFAULT_USER_AGENT


def wsman_send_request(cl, request):
    r"""wsman_send_request(Client cl, XmlDoc request) -> int"""
    return _pywsman.wsman_send_request(cl, request)

def wsmc_transport_set_auth_request_func(cl, f):
    r"""wsmc_transport_set_auth_request_func(Client cl, wsman_auth_request_func_t f)"""
    return _pywsman.wsmc_transport_set_auth_request_func(cl, f)

def wsman_is_auth_method(cl, method):
    r"""wsman_is_auth_method(Client cl, int method) -> int"""
    return _pywsman.wsman_is_auth_method(cl, method)

def wsmc_transport_init(cl, arg):
    r"""wsmc_transport_init(Client cl, void * arg) -> int"""
    return _pywsman.wsmc_transport_init(cl, arg)

def wsman_transport_close_transport(cl):
    r"""wsman_transport_close_transport(Client cl)"""
    return _pywsman.wsman_transport_close_transport(cl)

def wsmc_transport_fini(cl):
    r"""wsmc_transport_fini(Client cl)"""
    return _pywsman.wsmc_transport_fini(cl)

def wsman_transport_set_agent(cl, agent):
    r"""wsman_transport_set_agent(Client cl, char const * agent)"""
    return _pywsman.wsman_transport_set_agent(cl, agent)

def wsman_transport_get_agent(cl):
    r"""wsman_transport_get_agent(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_agent(cl)

def wsman_transport_set_userName(cl, user_name):
    r"""wsman_transport_set_userName(Client cl, char const * user_name)"""
    return _pywsman.wsman_transport_set_userName(cl, user_name)

def wsman_transport_get_userName(cl):
    r"""wsman_transport_get_userName(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_userName(cl)

def wsman_transport_set_password(cl, password):
    r"""wsman_transport_set_password(Client cl, char const * password)"""
    return _pywsman.wsman_transport_set_password(cl, password)

def wsman_transport_get_password(cl):
    r"""wsman_transport_get_password(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_password(cl)

def wsman_transport_set_proxy_username(cl, proxy_username):
    r"""wsman_transport_set_proxy_username(Client cl, char const * proxy_username)"""
    return _pywsman.wsman_transport_set_proxy_username(cl, proxy_username)

def wsman_transport_get_proxy_username(cl):
    r"""wsman_transport_get_proxy_username(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_proxy_username(cl)

def wsman_transport_set_proxy_password(cl, proxy_password):
    r"""wsman_transport_set_proxy_password(Client cl, char const * proxy_password)"""
    return _pywsman.wsman_transport_set_proxy_password(cl, proxy_password)

def wsman_transport_get_proxy_password(cl):
    r"""wsman_transport_get_proxy_password(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_proxy_password(cl)

def wsman_transport_set_auth_method(cl, am):
    r"""wsman_transport_set_auth_method(Client cl, char const * am)"""
    return _pywsman.wsman_transport_set_auth_method(cl, am)

def wsman_transport_get_auth_method(cl):
    r"""wsman_transport_get_auth_method(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_auth_method(cl)

def wsmc_transport_get_auth_name(auth):
    r"""wsmc_transport_get_auth_name(wsman_auth_type_t auth) -> char const *"""
    return _pywsman.wsmc_transport_get_auth_name(auth)

def wsmc_transport_get_auth_value(cl):
    r"""wsmc_transport_get_auth_value(Client cl) -> wsman_auth_type_t"""
    return _pywsman.wsmc_transport_get_auth_value(cl)

def wsman_transport_get_last_error_string(err):
    r"""wsman_transport_get_last_error_string(WS_LASTERR_Code err) -> char *"""
    return _pywsman.wsman_transport_get_last_error_string(err)

def wsman_transport_set_timeout(cl, timeout):
    r"""wsman_transport_set_timeout(Client cl, unsigned long timeout)"""
    return _pywsman.wsman_transport_set_timeout(cl, timeout)

def wsman_transport_get_timeout(cl):
    r"""wsman_transport_get_timeout(Client cl) -> unsigned long"""
    return _pywsman.wsman_transport_get_timeout(cl)

def wsman_transport_set_verify_peer(cl, value):
    r"""wsman_transport_set_verify_peer(Client cl, unsigned int value)"""
    return _pywsman.wsman_transport_set_verify_peer(cl, value)

def wsman_transport_get_verify_peer(cl):
    r"""wsman_transport_get_verify_peer(Client cl) -> unsigned int"""
    return _pywsman.wsman_transport_get_verify_peer(cl)

def wsman_transport_set_verify_host(cl, value):
    r"""wsman_transport_set_verify_host(Client cl, unsigned int value)"""
    return _pywsman.wsman_transport_set_verify_host(cl, value)

def wsman_transport_get_verify_host(cl):
    r"""wsman_transport_get_verify_host(Client cl) -> unsigned int"""
    return _pywsman.wsman_transport_get_verify_host(cl)

def wsman_transport_set_crlcheck(cl, value):
    r"""wsman_transport_set_crlcheck(Client cl, unsigned int value)"""
    return _pywsman.wsman_transport_set_crlcheck(cl, value)

def wsman_transport_get_crlcheck(cl):
    r"""wsman_transport_get_crlcheck(Client cl) -> unsigned int"""
    return _pywsman.wsman_transport_get_crlcheck(cl)

def wsman_transport_set_crlfile(cl, arg):
    r"""wsman_transport_set_crlfile(Client cl, char const * arg)"""
    return _pywsman.wsman_transport_set_crlfile(cl, arg)

def wsman_transport_get_crlfile(cl):
    r"""wsman_transport_get_crlfile(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_crlfile(cl)

def wsman_transport_set_proxy(cl, proxy):
    r"""wsman_transport_set_proxy(Client cl, char const * proxy)"""
    return _pywsman.wsman_transport_set_proxy(cl, proxy)

def wsman_transport_get_proxy(cl):
    r"""wsman_transport_get_proxy(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_proxy(cl)

def wsman_transport_set_proxyauth(cl, pauth):
    r"""wsman_transport_set_proxyauth(Client cl, char const * pauth)"""
    return _pywsman.wsman_transport_set_proxyauth(cl, pauth)

def wsman_transport_get_proxyauth(cl):
    r"""wsman_transport_get_proxyauth(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_proxyauth(cl)

def wsman_transport_set_cainfo(cl, cainfo):
    r"""wsman_transport_set_cainfo(Client cl, char const * cainfo)"""
    return _pywsman.wsman_transport_set_cainfo(cl, cainfo)

def wsman_transport_get_cainfo(cl):
    r"""wsman_transport_get_cainfo(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_cainfo(cl)

def wsman_transport_set_certhumbprint(cl, arg):
    r"""wsman_transport_set_certhumbprint(Client cl, char const * arg)"""
    return _pywsman.wsman_transport_set_certhumbprint(cl, arg)

def wsman_transport_get_certhumbprint(cl):
    r"""wsman_transport_get_certhumbprint(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_certhumbprint(cl)

def wsman_transport_set_capath(cl, capath):
    r"""wsman_transport_set_capath(Client cl, char const * capath)"""
    return _pywsman.wsman_transport_set_capath(cl, capath)

def wsman_transport_get_capath(cl):
    r"""wsman_transport_get_capath(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_capath(cl)

def wsman_transport_set_caoid(cl, oid):
    r"""wsman_transport_set_caoid(Client cl, char const * oid)"""
    return _pywsman.wsman_transport_set_caoid(cl, oid)

def wsman_transport_get_caoid(cl):
    r"""wsman_transport_get_caoid(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_caoid(cl)

def wsman_transport_set_cert(cl, cert):
    r"""wsman_transport_set_cert(Client cl, char const * cert)"""
    return _pywsman.wsman_transport_set_cert(cl, cert)

def wsman_transport_get_cert(cl):
    r"""wsman_transport_get_cert(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_cert(cl)

def wsman_transport_set_key(cl, key):
    r"""wsman_transport_set_key(Client cl, char const * key)"""
    return _pywsman.wsman_transport_set_key(cl, key)

def wsman_transport_get_key(cl):
    r"""wsman_transport_get_key(Client cl) -> char *"""
    return _pywsman.wsman_transport_get_key(cl)
class ClientOptions(object):
    r"""Proxy of C client_opt_t struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self):
        r"""__init__(ClientOptions self) -> ClientOptions"""
        _pywsman.ClientOptions_swiginit(self, _pywsman.new_ClientOptions())
    __swig_destroy__ = _pywsman.delete_ClientOptions

    def set_dump_request(self):
        r"""set_dump_request(ClientOptions self)"""
        return _pywsman.ClientOptions_set_dump_request(self)

    def clear_dump_request(self):
        r"""clear_dump_request(ClientOptions self)"""
        return _pywsman.ClientOptions_clear_dump_request(self)

    def set_flags(self, flags):
        r"""set_flags(ClientOptions self, unsigned long flags)"""
        return _pywsman.ClientOptions_set_flags(self, flags)

    def get_flags(self):
        r"""get_flags(ClientOptions self) -> unsigned long"""
        return _pywsman.ClientOptions_get_flags(self)

    def clear_flags(self, flags):
        r"""clear_flags(ClientOptions self, unsigned long flags)"""
        return _pywsman.ClientOptions_clear_flags(self, flags)

    def reset_flags(self):
        r"""reset_flags(ClientOptions self)"""
        return _pywsman.ClientOptions_reset_flags(self)

    def set_max_envelope_size(self, size):
        r"""set_max_envelope_size(ClientOptions self, unsigned long size)"""
        return _pywsman.ClientOptions_set_max_envelope_size(self, size)

    def get_max_envelope_size(self):
        r"""get_max_envelope_size(ClientOptions self) -> unsigned long"""
        return _pywsman.ClientOptions_get_max_envelope_size(self)

    def set_max_elements(self, elements):
        r"""set_max_elements(ClientOptions self, int elements)"""
        return _pywsman.ClientOptions_set_max_elements(self, elements)

    def get_max_elements(self):
        r"""get_max_elements(ClientOptions self) -> int"""
        return _pywsman.ClientOptions_get_max_elements(self)

    def set_timeout(self, timeout):
        r"""set_timeout(ClientOptions self, unsigned long timeout)"""
        return _pywsman.ClientOptions_set_timeout(self, timeout)

    def get_timeout(self):
        r"""get_timeout(ClientOptions self) -> unsigned long"""
        return _pywsman.ClientOptions_get_timeout(self)

    def set_fragment(self, fragment):
        r"""set_fragment(ClientOptions self, char * fragment)"""
        return _pywsman.ClientOptions_set_fragment(self, fragment)

    def get_fragment(self):
        r"""get_fragment(ClientOptions self) -> char const *"""
        return _pywsman.ClientOptions_get_fragment(self)

    def set_cim_namespace(self, cim_namespace):
        r"""set_cim_namespace(ClientOptions self, char * cim_namespace)"""
        return _pywsman.ClientOptions_set_cim_namespace(self, cim_namespace)

    def get_cim_namespace(self):
        r"""get_cim_namespace(ClientOptions self) -> char const *"""
        return _pywsman.ClientOptions_get_cim_namespace(self)

    def set_reference(self, reference):
        r"""set_reference(ClientOptions self, char const * reference)"""
        return _pywsman.ClientOptions_set_reference(self, reference)

    def get_reference(self):
        r"""get_reference(ClientOptions self) -> char const *"""
        return _pywsman.ClientOptions_get_reference(self)

    def add_option(self, key, value):
        r"""add_option(ClientOptions self, char const * key, char const * value)"""
        return _pywsman.ClientOptions_add_option(self, key, value)

    def add_selector(self, key, value):
        r"""add_selector(ClientOptions self, char const * key, char const * value)"""
        return _pywsman.ClientOptions_add_selector(self, key, value)

    def add_property_array_item(self, key, value):
        r"""add_property_array_item(ClientOptions self, char const * key, char const * value)"""
        return _pywsman.ClientOptions_add_property_array_item(self, key, value)

    def add_property(self, *args):
        r"""
        add_property(ClientOptions self, char const * key, char const * value)
        add_property(ClientOptions self, char const * key, EndPointReference epr)
        """
        return _pywsman.ClientOptions_add_property(self, *args)

    def set_delivery_uri(self, delivery_uri):
        r"""set_delivery_uri(ClientOptions self, char const * delivery_uri)"""
        return _pywsman.ClientOptions_set_delivery_uri(self, delivery_uri)

    def delivery_uri(self):
        r"""delivery_uri(ClientOptions self) -> char const *"""
        return _pywsman.ClientOptions_delivery_uri(self)

    def set_sub_expiry(self, event_subscription_expire):
        r"""set_sub_expiry(ClientOptions self, float event_subscription_expire)"""
        return _pywsman.ClientOptions_set_sub_expiry(self, event_subscription_expire)

    def sub_expiry(self):
        r"""sub_expiry(ClientOptions self) -> float"""
        return _pywsman.ClientOptions_sub_expiry(self)

    def set_heartbeat_interval(self, heartbeat_interval):
        r"""set_heartbeat_interval(ClientOptions self, float heartbeat_interval)"""
        return _pywsman.ClientOptions_set_heartbeat_interval(self, heartbeat_interval)

    def heartbeat_interval(self):
        r"""heartbeat_interval(ClientOptions self) -> float"""
        return _pywsman.ClientOptions_heartbeat_interval(self)

    def set_delivery_mode(self, delivery_mode):
        r"""set_delivery_mode(ClientOptions self, unsigned int delivery_mode)"""
        return _pywsman.ClientOptions_set_delivery_mode(self, delivery_mode)

    def delivery_mode(self):
        r"""delivery_mode(ClientOptions self) -> int"""
        return _pywsman.ClientOptions_delivery_mode(self)

    def set_delivery_security_mode(self, delivery_sec_mode):
        r"""set_delivery_security_mode(ClientOptions self, unsigned int delivery_sec_mode)"""
        return _pywsman.ClientOptions_set_delivery_security_mode(self, delivery_sec_mode)

    def delivery_sec_mode(self):
        r"""delivery_sec_mode(ClientOptions self) -> int"""
        return _pywsman.ClientOptions_delivery_sec_mode(self)

    def set_locale(self, locale):
        r"""set_locale(ClientOptions self, char const * locale)"""
        return _pywsman.ClientOptions_set_locale(self, locale)

    def locale(self):
        r"""locale(ClientOptions self) -> char const *"""
        return _pywsman.ClientOptions_locale(self)

# Register ClientOptions in _pywsman:
_pywsman.ClientOptions_swigregister(ClientOptions)
class Client(object):
    r"""Proxy of C _WsManClient struct."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(Client self, char const * uri) -> Client
        __init__(Client self, char const * hostname, int const port, char const * path, char const * scheme, char const * username, char const * password) -> Client
        """
        _pywsman.Client_swiginit(self, _pywsman.new_Client(*args))
    __swig_destroy__ = _pywsman.delete_Client

    def set_dumpfile(self, f):
        r"""set_dumpfile(Client self, FILE * f)"""
        return _pywsman.Client_set_dumpfile(self, f)

    def response_code(self):
        r"""response_code(Client self) -> long"""
        return _pywsman.Client_response_code(self)

    def scheme(self):
        r"""scheme(Client self) -> char *"""
        return _pywsman.Client_scheme(self)

    def host(self):
        r"""host(Client self) -> char *"""
        return _pywsman.Client_host(self)

    def port(self):
        r"""port(Client self) -> int"""
        return _pywsman.Client_port(self)

    def path(self):
        r"""path(Client self) -> char *"""
        return _pywsman.Client_path(self)

    def user(self):
        r"""user(Client self) -> char *"""
        return _pywsman.Client_user(self)

    def password(self):
        r"""password(Client self) -> char *"""
        return _pywsman.Client_password(self)

    def transport(self):
        r"""transport(Client self) -> Transport"""
        return _pywsman.Client_transport(self)

    def send_request(self, request):
        r"""send_request(Client self, XmlDoc request) -> int"""
        return _pywsman.Client_send_request(self, request)

    def build_envelope_from_response(self):
        r"""build_envelope_from_response(Client self) -> XmlDoc"""
        return _pywsman.Client_build_envelope_from_response(self)

    def encoding(self):
        r"""encoding(Client self) -> char *"""
        return _pywsman.Client_encoding(self)

    def set_encoding(self, encoding):
        r"""set_encoding(Client self, char const * encoding)"""
        return _pywsman.Client_set_encoding(self, encoding)

    def identify(self, options):
        r"""identify(Client self, ClientOptions options) -> XmlDoc"""
        return _pywsman.Client_identify(self, options)

    def get_from_epr(self, options, epr):
        r"""get_from_epr(Client self, ClientOptions options, EndPointReference epr) -> XmlDoc"""
        return _pywsman.Client_get_from_epr(self, options, epr)

    def delete_from_epr(self, options, epr):
        r"""delete_from_epr(Client self, ClientOptions options, EndPointReference epr) -> XmlDoc"""
        return _pywsman.Client_delete_from_epr(self, options, epr)

    def enumerate(self, options, filter, resource_uri):
        r"""enumerate(Client self, ClientOptions options, Filter filter, char * resource_uri) -> XmlDoc"""
        return _pywsman.Client_enumerate(self, options, filter, resource_uri)

    def pull(self, options, filter, resource_uri, context):
        r"""pull(Client self, ClientOptions options, Filter filter, char const * resource_uri, char const * context) -> XmlDoc"""
        return _pywsman.Client_pull(self, options, filter, resource_uri, context)

    def create(self, *args):
        r"""create(Client self, ClientOptions options, char const * resource_uri, char const * data, size_t size, char const * encoding="utf-8") -> XmlDoc"""
        return _pywsman.Client_create(self, *args)

    def put(self, *args):
        r"""put(Client self, ClientOptions options, char const * resource_uri, char const * data, size_t size, char const * encoding="utf-8") -> XmlDoc"""
        return _pywsman.Client_put(self, *args)

    def release(self, options, resource_uri, context):
        r"""release(Client self, ClientOptions options, char const * resource_uri, char const * context) -> XmlDoc"""
        return _pywsman.Client_release(self, options, resource_uri, context)

    def get(self, options, resource_uri):
        r"""get(Client self, ClientOptions options, char const * resource_uri) -> XmlDoc"""
        return _pywsman.Client_get(self, options, resource_uri)

    def delete(self, options, resource_uri):
        r"""delete(Client self, ClientOptions options, char const * resource_uri) -> XmlDoc"""
        return _pywsman.Client_delete(self, options, resource_uri)

    def invoke(self, options, resource_uri, method, data=None):
        r"""invoke(Client self, ClientOptions options, char const * resource_uri, char const * method, XmlDoc data=None) -> XmlDoc"""
        return _pywsman.Client_invoke(self, options, resource_uri, method, data)

    def subscribe(self, options, filter, resource_uri):
        r"""subscribe(Client self, ClientOptions options, Filter filter, char const * resource_uri) -> XmlDoc"""
        return _pywsman.Client_subscribe(self, options, filter, resource_uri)

    def unsubscribe(self, options, filter, resource_uri, identifier):
        r"""unsubscribe(Client self, ClientOptions options, Filter filter, char const * resource_uri, char const * identifier) -> XmlDoc"""
        return _pywsman.Client_unsubscribe(self, options, filter, resource_uri, identifier)

    def renew(self, options, resource_uri, identifier):
        r"""renew(Client self, ClientOptions options, char * resource_uri, char * identifier) -> XmlDoc"""
        return _pywsman.Client_renew(self, options, resource_uri, identifier)

    def fault_string(self):
        r"""fault_string(Client self) -> char *"""
        return _pywsman.Client_fault_string(self)

    def last_error(self):
        r"""last_error(Client self) -> int"""
        return _pywsman.Client_last_error(self)

# Register Client in _pywsman:
_pywsman.Client_swigregister(Client)

def set_debug(dbg):
    r"""set_debug(int dbg)"""
    return _pywsman.set_debug(dbg)

def get_debug():
    r"""get_debug() -> int"""
    return _pywsman.get_debug()

def create_soap_envelope():
    r"""create_soap_envelope() -> XmlDoc"""
    return _pywsman.create_soap_envelope()

def create_doc_from_file(*args):
    r"""create_doc_from_file(char const * filename, char const * encoding="UTF-8") -> XmlDoc"""
    return _pywsman.create_doc_from_file(*args)

def create_doc_from_string(*args):
    r"""create_doc_from_string(char const * buf, char const * encoding="UTF-8") -> XmlDoc"""
    return _pywsman.create_doc_from_string(*args)

def uri_prefix(classname):
    r"""uri_prefix(char const * classname) -> char const *"""
    return _pywsman.uri_prefix(classname)

